@@ -115,7 +115,7 @@ void
 click_check_button_cb (GtkWidget	*widget, 
 	       	       gpointer 	data)
 {
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)) == TRUE) {
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget))) {
 		gtk_widget_show (interface.additional_constraints);
 		gtk_window_set_geometry_hints (GTK_WINDOW (interface.main_window), 
 		                               GTK_WIDGET (interface.main_window),
@@ -142,7 +142,7 @@ click_find_cb (GtkWidget	*widget,
 {
 	gchar *command;
 
-	if (search_command.not_running_timeout == TRUE) {
+	if (search_command.not_running_timeout) {
 		return;
 	}
 
@@ -196,7 +196,7 @@ add_constraint_cb (GtkWidget 	*widget,
 	menu = gtk_option_menu_get_menu (GTK_OPTION_MENU(interface.constraint_menu));
 	item = gtk_menu_get_active (GTK_MENU(menu));
 	
-	if (GTK_WIDGET_SENSITIVE(item) == TRUE) {
+	if (GTK_WIDGET_SENSITIVE(item)) {
 		add_constraint (interface.selected_constraint, NULL, FALSE);
 	}
 }
@@ -226,8 +226,8 @@ void
 constraint_activate_cb (GtkWidget 	*widget, 
 			gpointer 	data)
 {
-	if ((GTK_WIDGET_VISIBLE (interface.find_button) == TRUE) && 
-	    (GTK_WIDGET_SENSITIVE (interface.find_button) == TRUE)) {
+	if ((GTK_WIDGET_VISIBLE (interface.find_button)) && 
+	    (GTK_WIDGET_SENSITIVE (interface.find_button))) {
 		click_find_cb (interface.find_button, NULL);
 	}	 
 }
@@ -244,11 +244,10 @@ constraint_update_info_cb (GtkWidget 	*widget,
 }
 
 void
-constraint_menu_toggled_cb(GtkWidget 	*widget, 
-			   gpointer 	data)
+constraint_menu_item_activate_cb (GtkWidget  *widget, 
+                                  gpointer   data)
 {
-	if (GTK_CHECK_MENU_ITEM(widget)->active)
-		interface.selected_constraint = (long)data;
+	interface.selected_constraint = (long)data;
 }
 
 void
@@ -266,10 +265,12 @@ constraint_entry_changed_cb (GtkWidget 	*widget,
 
 	if (look_in_folder_string == NULL) {
 		gtk_widget_set_sensitive (interface.find_button, FALSE);
+		g_free (look_in_folder_string);
 		return;
 	}
 	
 	gtk_widget_set_sensitive (interface.find_button, TRUE);
+	g_free (look_in_folder_string);
 }
 	
 
@@ -277,8 +278,8 @@ void
 file_is_named_activate_cb (GtkWidget 	*widget, 
 			   gpointer 	data)
 {
-	if ((GTK_WIDGET_VISIBLE (interface.find_button) == TRUE) && 
-	    (GTK_WIDGET_SENSITIVE (interface.find_button) == TRUE)) {
+	if ((GTK_WIDGET_VISIBLE (interface.find_button)) && 
+	    (GTK_WIDGET_SENSITIVE (interface.find_button))) {
 		click_find_cb (interface.find_button, NULL);
 	}
 }
@@ -489,7 +490,7 @@ file_button_press_event_cb (GtkWidget 		*widget,
 	if (gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW(interface.tree), event->x, event->y,
 		&path, NULL, NULL, NULL)) {
 		
-		if ((event->button == 1 || event->button == 3)
+		if ((event->button == 1 || event->button == 2 || event->button == 3)
 			&& gtk_tree_selection_path_is_selected (gtk_tree_view_get_selection (GTK_TREE_VIEW(interface.tree)), path)) {
 			
 			row_selected_by_button_press_event = FALSE;
@@ -532,14 +533,14 @@ file_button_release_event_cb (GtkWidget 	*widget,
 		return FALSE;
 	}
 		
-	if (event->button == 1) {
+	if (event->button == 1 || event->button == 2) {
 
 		GtkTreePath *path;
 
 		if (gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW(interface.tree), event->x, event->y,
 			&path, NULL, NULL, NULL)) {
 			if ((event->state & GDK_SHIFT_MASK) || (event->state & GDK_CONTROL_MASK)) {
-				if (row_selected_by_button_press_event == TRUE) {
+				if (row_selected_by_button_press_event) {
 					gtk_tree_selection_select_path (gtk_tree_view_get_selection (GTK_TREE_VIEW(interface.tree)), path);
 				}
 				else {
@@ -862,14 +863,16 @@ save_results_cb (GtkFileSelection *selector,
 	GtkListStore *store;
 	GtkTreeIter iter;
 	gint n_children, i;
+	gchar *utf8;
 	
 	store = interface.model;
 	
-	interface.save_results_file = (gchar *)gtk_file_selection_get_filename(GTK_FILE_SELECTION(interface.file_selector));
+	interface.save_results_file = (gchar *)gtk_file_selection_get_filename (GTK_FILE_SELECTION (interface.file_selector));
+	utf8 = g_filename_to_utf8 (interface.save_results_file, -1, NULL, NULL, NULL);
 	
-	if (g_file_test (interface.save_results_file, G_FILE_TEST_EXISTS) == TRUE) {
+	if (g_file_test (interface.save_results_file, G_FILE_TEST_EXISTS)) {
 		
-		if (g_file_test (interface.save_results_file, G_FILE_TEST_IS_DIR) == TRUE) {
+		if (g_file_test (interface.save_results_file, G_FILE_TEST_IS_DIR)) {
 			GtkWidget *dialog;
 			gchar *title_msg;
 			gchar *error_msg;
@@ -900,8 +903,7 @@ save_results_cb (GtkFileSelection *selector,
 			gchar     *text;
 			gint      response;
 				 
-			text = g_strdup_printf (_("The contents of the file \"%s\" will be lost."), 
-			                        interface.save_results_file);
+			text = g_strdup_printf (_("The contents of the file \"%s\" will be lost."), utf8);
 			
 			dialog = gsearchtool_hig_dialog_new (GTK_WINDOW (interface.main_window),
 			                                     0 /* flags */,
@@ -950,8 +952,7 @@ save_results_cb (GtkFileSelection *selector,
 		gchar *error_msg;
 		
 		title_msg = g_strdup_printf (_("Could not save document \"%s\" to %s"), 
-		                             g_path_get_basename (interface.save_results_file),
-					     g_path_get_dirname (interface.save_results_file));
+		                             g_path_get_basename (utf8), g_path_get_dirname (utf8));
 					     
 		error_msg = g_strdup_printf ("%s",
 		_("You may not have write permissions to the document.  The document is not saved."));
@@ -970,6 +971,7 @@ save_results_cb (GtkFileSelection *selector,
 		g_free (title_msg);
 		g_free (error_msg);
 	}
+	g_free (utf8);
 }
 
 void
@@ -1045,8 +1047,8 @@ look_in_folder_key_press_cb (GtkWidget    	*widget,
 
 	if (event->keyval == GDK_Return)
 	{
-		if ((GTK_WIDGET_VISIBLE (interface.find_button) == TRUE) && 
-		    (GTK_WIDGET_SENSITIVE (interface.find_button) == TRUE)) {
+		if ((GTK_WIDGET_VISIBLE (interface.find_button)) && 
+		    (GTK_WIDGET_SENSITIVE (interface.find_button))) {
 			click_find_cb (interface.find_button, NULL);
 		}
 	}
