@@ -49,6 +49,9 @@ click_find_cb	 		(GtkWidget 	*widget,
 void
 click_stop_cb 			(GtkWidget 	*widget, 
 	       			 gpointer 	data);
+void
+click_check_button_cb		(GtkWidget	*widget, 
+				 gpointer 	data);
 void   
 size_allocate_cb 		(GtkWidget 	*widget,
 				 GtkAllocation  *allocation, 
@@ -66,8 +69,8 @@ void
 constraint_update_info_cb 	(GtkWidget 	*widget, 
 				 gpointer 	data);	
 void    
-constraint_menu_toggled_cb	(GtkWidget 	*widget, 
-				 gpointer 	data);
+constraint_menu_item_activate_cb(GtkWidget 	*widget,
+                                 gpointer 	data);
 void    
 constraint_entry_changed_cb 	(GtkWidget 	*widget, 
 				 gpointer 	data);
@@ -94,6 +97,13 @@ drag_file_cb  			(GtkWidget          *widget,
 	       			 guint               info,
 	       			 guint               time,
 	       			 gpointer            data);
+void  
+drag_data_animation_cb		(GtkWidget          *widget,
+	      			 GdkDragContext     *context,
+	       			 GtkSelectionData   *selection_data,
+	       			 guint               info,
+	       			 guint               time,
+	       			 gpointer            data);
 void    
 show_file_selector_cb 		(GtkWidget 	*widget,
 				 gpointer 	data);
@@ -131,6 +141,13 @@ gboolean
 file_button_press_event_cb	(GtkWidget 	*widget, 
 				 GdkEventButton *event, 
 				 gpointer 	data);
+gboolean	
+file_key_press_event_cb		(GtkWidget 	*widget,
+				 GdkEventKey    *event,
+				 gpointer 	data);
+gboolean
+not_running_timeout_cb 		(gpointer data);
+
 #ifdef __cplusplus
 }
 #endif
