@@ -316,8 +316,12 @@ get_readable_date (const time_t file_time_raw)
 	g_date_free (today);
 	g_date_free (file_date);
 			
-	/* the format varies depending on age of file. */
 	if (file_date_age == 0)	{
+	/* Translators:  Below are the strings displayed in the 'Date Modified'
+	   column of the list view.  The format of this string can vary depending 
+	   on age of a file.  Please modify the format of the timestamp to match
+	   your locale.  For example, to display 24 hour time replace the '%-I' 
+	   with '%-H' and remove the '%p'.  (See bugzilla report #120434.) */
 		format = g_strdup(_("today at %-I:%M %p"));
 	} else if (file_date_age == 1) {
 		format = g_strdup(_("yesterday at %-I:%M %p"));
@@ -484,6 +488,7 @@ get_file_icon_with_mime_type (const gchar *filename,
 
 	icon_path = gnome_icon_theme_lookup_icon (interface.icon_theme, icon_name, ICON_SIZE, 
 						  &icon_data, &base_size);
+	g_free (icon_name);
 	return icon_path;	
 }
 
@@ -563,7 +568,7 @@ open_file_with_application (const gchar *filename)
 		gnome_execute_async(NULL, argc, argv);	
 		gnome_vfs_mime_application_free(mimeApp);
 		g_free (command_line);	
-		g_free(argv);
+		g_strfreev (argv);
 		return TRUE;
 	}
 	return FALSE;
