@@ -72,8 +72,8 @@ struct _FindOptionTemplate {
 static FindOptionTemplate templates[] = {
 	{ SEARCH_CONSTRAINT_TEXT, "-exec grep -c '%s' {} \\;", N_("Contains the _text"), FALSE },
 	{ SEARCH_CONSTRAINT_SEPARATOR, NULL, NULL, TRUE },
-	{ SEARCH_CONSTRAINT_TIME, "-mtime -%d", N_("_Date modified less than (days)"), FALSE },
-	{ SEARCH_CONSTRAINT_TIME, "-mtime +%d", N_("Date modified more than (da_ys)"), FALSE },
+	{ SEARCH_CONSTRAINT_TIME_LESS, "-mtime -%d", N_("_Date modified less than (days)"), FALSE },
+	{ SEARCH_CONSTRAINT_TIME_MORE, "\\( -mtime +%d -o -mtime %d \\)", N_("Date modified more than (da_ys)"), FALSE },
 	{ SEARCH_CONSTRAINT_SEPARATOR, NULL, NULL, TRUE },
 	{ SEARCH_CONSTRAINT_NUMBER, "-size +%uc", N_("S_ize at least (kilobytes)"), FALSE }, 
 	{ SEARCH_CONSTRAINT_NUMBER, "-size -%uc", N_("Si_ze at most (kilobytes)"), FALSE },
@@ -299,9 +299,14 @@ build_search_command (void)
 	look_in_folder_locale = g_locale_from_utf8 (look_in_folder_utf8, -1, NULL, NULL, NULL);
 	gnome_entry_prepend_history (GNOME_ENTRY(gnome_file_entry_gnome_entry (GNOME_FILE_ENTRY(interface.look_in_folder_entry))), 
 				     TRUE, look_in_folder_utf8);
+	g_free (look_in_folder_utf8);
 	
 	if (!file_extension_is (look_in_folder_locale, G_DIR_SEPARATOR_S)) {
+		gchar *tmp;
+		
+		tmp = look_in_folder_locale;
 		look_in_folder_locale = g_strconcat (look_in_folder_locale, G_DIR_SEPARATOR_S, NULL);
+		g_free (tmp);
 	}
 	search_command.look_in_folder = g_strdup(look_in_folder_locale);
 	
@@ -404,12 +409,19 @@ build_search_command (void)
 					  		(constraint->data.number * 1024));
 				g_string_append_c (command, ' ');
 				break;
-			case SEARCH_CONSTRAINT_TIME:
+			case SEARCH_CONSTRAINT_TIME_LESS:
 				g_string_append_printf (command,
 					 		templates[constraint->constraint_id].option,
 					  		constraint->data.time);
 				g_string_append_c (command, ' ');
 				break;
+			case SEARCH_CONSTRAINT_TIME_MORE:
+				g_string_append_printf (command,
+					 		templates[constraint->constraint_id].option,
+					  		constraint->data.time,
+							constraint->data.time);
+				g_string_append_c (command, ' ');
+				break;
 			default:
 		        	break;
 			}
@@ -538,8 +550,6 @@ make_list_of_templates (void)
 	gboolean ACTIVATE_MENU_OPTION = TRUE;
 	GtkWidget *menu;
 	GtkWidget *menuitem;
-	GtkWidget *separator;
-	GSList    *group = NULL;
 	gint i;
 
 	menu = gtk_menu_new ();
@@ -547,20 +557,16 @@ make_list_of_templates (void)
 	for(i=0; templates[i].type != SEARCH_CONSTRAINT_END; i++) {
 		
 		if (templates[i].type == SEARCH_CONSTRAINT_SEPARATOR) {
-			menuitem = gtk_menu_item_new ();
-			separator = gtk_hseparator_new ();
-			gtk_container_add (GTK_CONTAINER (menuitem), separator);	
+			menuitem = gtk_separator_menu_item_new ();
 			gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
-			gtk_widget_show (separator);
 			gtk_widget_show (menuitem);
 		} 
 		else {
 			gchar *text = remove_mnemonic_character (_(templates[i].desc));
-			menuitem = gtk_radio_menu_item_new_with_label (group, text);
-			g_signal_connect (G_OBJECT(menuitem), "toggled",
-					  G_CALLBACK(constraint_menu_toggled_cb),
+			menuitem = gtk_menu_item_new_with_label (text);
+			g_signal_connect (G_OBJECT(menuitem), "activate",
+					  G_CALLBACK(constraint_menu_item_activate_cb),
 		        		  (gpointer)(long)i);
-			group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menuitem));
 			gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 			gtk_widget_show (menuitem);
 			g_free (text);
@@ -591,7 +597,8 @@ set_constraint_info_defaults (SearchConstraint *opt)
 	case SEARCH_CONSTRAINT_NUMBER:
 		opt->data.number = 0;
 		break;
-	case SEARCH_CONSTRAINT_TIME:
+	case SEARCH_CONSTRAINT_TIME_LESS:
+	case SEARCH_CONSTRAINT_TIME_MORE:
 		opt->data.time = 0;
 		break;
 	default:
@@ -610,7 +617,8 @@ update_constraint_info (SearchConstraint 	*constraint,
 	case SEARCH_CONSTRAINT_NUMBER:
 		sscanf (info, "%d", &constraint->data.number);
 		break;
-	case SEARCH_CONSTRAINT_TIME:
+	case SEARCH_CONSTRAINT_TIME_LESS:
+	case SEARCH_CONSTRAINT_TIME_MORE:
 		sscanf (info, "%d", &constraint->data.time);
 		break;
 	default:
@@ -792,7 +800,8 @@ get_desktop_item_name (void)
 	look_in_folder_locale = g_locale_from_utf8 (look_in_folder_utf8 != NULL ? look_in_folder_utf8 : "", 
 	                                            -1, NULL, NULL, NULL);
 	g_string_append (gs, g_strdup_printf ("&path=%s", look_in_folder_locale));
-	g_free (look_in_folder_locale); 
+	g_free (look_in_folder_locale);
+	g_free (look_in_folder_utf8); 
 
 	if (GTK_WIDGET_VISIBLE(interface.additional_constraints)) {
 		for (list = interface.selected_constraints; list != NULL; list = g_list_next (list)) {
@@ -1112,6 +1121,7 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 				 gpointer 	data) 
 {
 	struct _SearchStruct *search_data = data;
+	gboolean             broken_pipe = FALSE;
 
 	if ((condition == G_IO_IN) || (condition == G_IO_IN + G_IO_HUP)) { 
 	
@@ -1131,13 +1141,21 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 			gchar *utf8 = NULL;
 			gchar *filename = NULL;
 			
-			if (search_data->running != RUNNING) {
+			if (search_data->running == MAKE_IT_STOP) {
+				broken_pipe = TRUE;
+				break;
+			} 
+			else if (search_data->running != RUNNING) {
 			 	break;
 			}
 			
 			do {
 				status = g_io_channel_read_line_string (ioc, string, NULL, &error);
 				
+				if (status == G_IO_STATUS_EOF) {
+					broken_pipe = TRUE;
+				}
+				
 				while (gtk_events_pending ()) {
 					if (search_data->running == MAKE_IT_QUIT) {
 						return FALSE;
@@ -1145,7 +1163,11 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 					gtk_main_iteration (); 				
 				}
 				
-			} while (status == G_IO_STATUS_AGAIN);
+			} while (status == G_IO_STATUS_AGAIN && broken_pipe == FALSE);
+			
+			if (broken_pipe == TRUE) {
+				break;
+			}
 			
 			if (status != G_IO_STATUS_NORMAL) {
 				if (error != NULL) {
@@ -1215,12 +1237,13 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 		g_string_free (string, TRUE);
 	}
 
-	if (condition != G_IO_IN) { 
+	if (condition != G_IO_IN || broken_pipe == TRUE) { 
 	
 		gint   total_files;
 		gchar *status_bar_string = NULL;
 		gchar *title_bar_string = NULL;
 		gchar *search_status = g_strdup ("");
+		gchar  *tmp;
 		
 		if (search_data->running == MAKE_IT_STOP) {
 			search_status = g_strdup (_("(stopped)"));
@@ -1254,8 +1277,10 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 		}
 		gtk_label_set_text (GTK_LABEL (interface.results_label), status_bar_string);
 		
+		tmp = title_bar_string;
 		title_bar_string = g_strconcat (title_bar_string, " - ", _("Search for Files"), NULL);
 		gtk_window_set_title (GTK_WINDOW (interface.main_window), title_bar_string);
+		g_free (tmp);
 
 		stop_animation ();
 
@@ -1270,6 +1295,7 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 		g_io_channel_shutdown (ioc, TRUE, NULL);
 		g_free (status_bar_string);
 		g_free (title_bar_string);
+		g_free (search_status);
 		
 		return FALSE;
 	}
@@ -1284,6 +1310,7 @@ handle_search_command_stderr_io (GIOChannel 	*ioc,
 	struct _SearchStruct *search_data = data;
 	static GString       *error_msgs = NULL;
 	static gboolean      truncate_error_msgs = FALSE;
+	gboolean             broken_pipe = FALSE;
 	
 	if ((condition == G_IO_IN) || (condition == G_IO_IN + G_IO_HUP)) { 
 	
@@ -1305,6 +1332,10 @@ handle_search_command_stderr_io (GIOChannel 	*ioc,
 			do {
 				status = g_io_channel_read_line_string (ioc, string, NULL, &error);
 	
+				if (status == G_IO_STATUS_EOF) {
+					broken_pipe = TRUE;
+				}
+	
 				while (gtk_events_pending ()) {
 					if (search_data->running == MAKE_IT_QUIT) {
 						break;
@@ -1312,7 +1343,11 @@ handle_search_command_stderr_io (GIOChannel 	*ioc,
 					gtk_main_iteration ();
 				}
 					
-			} while (status == G_IO_STATUS_AGAIN);
+			} while (status == G_IO_STATUS_AGAIN && broken_pipe == FALSE);
+			
+			if (broken_pipe == TRUE) {
+				break;
+			}
 			
 			if (status != G_IO_STATUS_NORMAL) {
 				if (error != NULL) {
@@ -1339,7 +1374,7 @@ handle_search_command_stderr_io (GIOChannel 	*ioc,
 		g_free (utf8);
 	}
 	
-	if (condition != G_IO_IN) { 
+	if (condition != G_IO_IN || broken_pipe == TRUE) { 
 	
 		if (error_msgs != NULL) {
 
@@ -1403,6 +1438,7 @@ spawn_search_command (gchar *command)
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
 		g_error_free (error);
+		g_strfreev (argv);
 		return;
 	}	
 
@@ -1483,7 +1519,8 @@ create_constraint_box (SearchConstraint *opt, gchar *value)
 		break;
 	case SEARCH_CONSTRAINT_TEXT:
 	case SEARCH_CONSTRAINT_NUMBER:
-	case SEARCH_CONSTRAINT_TIME:
+	case SEARCH_CONSTRAINT_TIME_LESS:
+	case SEARCH_CONSTRAINT_TIME_MORE:
 		{
 			gchar *desc = g_strconcat (LEFT_LABEL_SPACING, _(templates[opt->constraint_id].desc), ":", NULL);
 			label = gtk_label_new_with_mnemonic (desc);
@@ -1689,7 +1726,7 @@ create_search_results_section (void)
 				     GTK_SELECTION_MULTIPLE);
 				     
 	gtk_drag_source_set (interface.tree, 
-			     GDK_BUTTON1_MASK,
+			     GDK_BUTTON1_MASK | GDK_BUTTON2_MASK,
 			     dnd_table, n_dnds, 
 			     GDK_ACTION_COPY | GDK_ACTION_MOVE);	
 
@@ -2031,6 +2068,8 @@ set_clone_command (gint *argcp, gchar ***argvp, gpointer client_data, gboolean e
 	look_in_folder_utf8 = gnome_file_entry_get_full_path (GNOME_FILE_ENTRY(interface.look_in_folder_entry), FALSE);
 	look_in_folder_locale = g_locale_from_utf8 (look_in_folder_utf8 != NULL ? look_in_folder_utf8 : "", 
 	                                            -1, NULL, NULL, NULL);
+	g_free (look_in_folder_utf8);
+	
 	if (escape_values)
 		tmp = g_shell_quote (look_in_folder_locale);
 	else
