@@ -53,7 +53,8 @@ typedef enum {
 	SEARCH_CONSTRAINT_BOOL, 
 	SEARCH_CONSTRAINT_TEXT,
 	SEARCH_CONSTRAINT_NUMBER,
-	SEARCH_CONSTRAINT_TIME,
+	SEARCH_CONSTRAINT_TIME_LESS,
+	SEARCH_CONSTRAINT_TIME_MORE,
 	SEARCH_CONSTRAINT_SEPARATOR
 } SearchConstraintType;
 
@@ -99,7 +100,6 @@ struct _InterfaceStruct {
 	GtkWidget 		*save_button;
 	GtkWidget 		*main_window;	
 	GtkWidget		*drawing_area;
-	GdkPixmap		*pixmap;
 	GdkPixbuf		*pixbuf;	
 	GtkWidget		*table;	
 	GtkWidget 		*file_selector;
